CPC Model Post Processing
================================

[![image](https://img.shields.io/pypi/v/cpc.mpp.svg)](https://pypi.python.org/pypi/cpc.mpp)

[![image](https://img.shields.io/travis/mikecharles/cpc.mpp.svg)](https://travis-ci.org/mikecharles/cpc.mpp)

Model post processing package

- Free software: Creative Commons license

Features
--------

-   TODO

Credits
-------

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.
